'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const Axios = require('axios');
const vue = require('vue');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

const Axios__default = /*#__PURE__*/_interopDefaultLegacy(Axios);

Axios__default["default"].defaults.timeout = 5000;
Axios__default["default"].defaults.headers.common.Accept = 'application/json';
Axios__default["default"].defaults.headers.common.ContentType = 'application/json';
const $axios = Axios__default["default"];

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types, @typescript-eslint/no-explicit-any
function isPromise(promise) {
    return !!promise && typeof promise.then === 'function';
}
async function wait(time = 2000) {
    return new Promise(resolve => {
        setTimeout(() => resolve(undefined), time);
    });
}

function useAxios(instance = $axios) {
    const CancelToken = Axios__default["default"].CancelToken;
    const source = CancelToken.source();
    const aborted = vue.ref(false);
    const abortMessage = vue.ref();
    const isLoading = vue.ref(false);
    const hasFailed = vue.ref(false);
    const isSuccessful = vue.ref(false);
    const isFinished = vue.ref(false);
    const status = vue.ref();
    const statusText = vue.ref();
    const response = vue.shallowRef();
    const data = vue.shallowRef();
    const error = vue.shallowRef();
    const headers = vue.ref();
    function abort(message) {
        if (isFinished.value || !isLoading.value)
            return;
        source.cancel(message);
        abortMessage.value = message;
    }
    function reset() {
        response.value = undefined;
        data.value = undefined;
        error.value = undefined;
        status.value = 0;
        statusText.value = undefined;
        abortMessage.value = undefined;
        isLoading.value = true;
        hasFailed.value = false;
        isSuccessful.value = false;
        aborted.value = false;
        isFinished.value = false;
    }
    function map(res) {
        status.value = res.status;
        status.value = res.status;
        statusText.value = res.statusText;
        isSuccessful.value = res.status < 400;
        hasFailed.value = !isSuccessful.value;
        data.value = res.data;
        headers.value = res.headers;
    }
    async function request(config) {
        reset();
        if (isPromise(config)) {
            const { url, options } = (await config);
            config = Object.assign({ url }, options);
        }
        try {
            response.value = await instance.request(Object.assign(Object.assign({}, config), { cancelToken: source.token }));
            map(response.value);
        }
        catch (_error) {
            error.value = _error;
            hasFailed.value = true;
        }
        finally {
            isLoading.value = false;
            isFinished.value = true;
        }
    }
    async function requestMock(config, res, delay) {
        reset();
        if (isPromise(config)) {
            const { url, options } = (await config);
            config = Object.assign({ url }, options);
        }
        try {
            await wait(delay);
            response.value = res;
            map(res);
        }
        catch (_error) {
            error.value = _error;
            hasFailed.value = true;
        }
        finally {
            isLoading.value = false;
            isFinished.value = true;
        }
    }
    function get(url, config) {
        return request(Object.assign(Object.assign({}, config), { method: 'GET', url }));
    }
    function head(url, config) {
        return request(Object.assign(Object.assign({}, config), { method: 'HEAD', url }));
    }
    function options(url, config) {
        return request(Object.assign(Object.assign({}, config), { method: 'OPTIONS', url }));
    }
    function post(url, data, config) {
        return request(Object.assign(Object.assign({}, config), { method: 'POST', url, data }));
    }
    function put(url, data, config) {
        return request(Object.assign(Object.assign({}, config), { method: 'PUT', url, data }));
    }
    function patch(url, data, config) {
        return request(Object.assign(Object.assign({}, config), { method: 'PATCH', url, data }));
    }
    function remove(url, config) {
        return request(Object.assign(Object.assign({}, config), { method: 'DELETE', url }));
    }
    return {
        data,
        response,
        error,
        headers,
        status,
        statusText,
        isLoading: isLoading,
        hasFailed,
        isSuccessful,
        isFinished,
        aborted,
        abortMessage,
        abort,
        request,
        requestMock,
        get,
        head,
        options,
        post,
        patch,
        put,
        remove,
    };
}

/* ============
 * Axios
 * ============
 *
 * Promise based HTTP client for the browser and node.js.
 * Because Vue Resource has been retired, Axios will now been used
 * to perform AJAX-requests.
 *
 * https://github.com/mzabriskie/axios
 */
const vueAxios = {
    async install(app, defaults) {
        $axios.defaults = Object.assign(Object.assign({}, $axios.defaults), defaults);
        app.config.globalProperties.$axios = $axios;
    },
};

exports.$axios = $axios;
exports.useAxios = useAxios;
exports.vueAxios = vueAxios;
//# sourceMappingURL=index.js.map
