import { Ref } from 'vue';
import { AxiosError, AxiosInstance, AxiosRequestConfig, AxiosResponse } from 'axios';
export interface RequestArgs {
    url: string;
    options: AxiosRequestConfig;
}
export interface AxiosResponseComposables<T, E = unknown, H = unknown> {
    response: Ref<AxiosResponse<T> | undefined>;
    data: Ref<T | undefined>;
    error: Ref<AxiosError<E> | undefined>;
    headers: Ref<H>;
    status: Ref<number>;
    statusText: Ref<string>;
    abortMessage: Ref<string>;
    hasFailed: Ref<boolean>;
    isFinished: Ref<boolean>;
    isSuccessful: Ref<boolean>;
    aborted: Ref<boolean>;
}
export interface AxiosComposables<T, E = unknown> extends AxiosResponseComposables<T, E> {
    isLoading: Ref<boolean>;
    abort: (message: string) => void;
    request: (config: AxiosRequestConfig | Promise<RequestArgs>) => Promise<void>;
    requestMock: (config: AxiosRequestConfig | Promise<RequestArgs>, response: AxiosResponse<T>, delay?: number) => Promise<void>;
    get: (url: string, config: AxiosRequestConfig) => Promise<void>;
    head: (url: string, config: AxiosRequestConfig) => Promise<void>;
    options: (url: string, config: AxiosRequestConfig) => Promise<void>;
    post: (url: string, data: T, config: AxiosRequestConfig) => Promise<void>;
    put: (url: string, data: T, config: AxiosRequestConfig) => Promise<void>;
    patch: (url: string, data: T, config: AxiosRequestConfig) => Promise<void>;
    remove: (url: string, config: AxiosRequestConfig) => Promise<void>;
}
export declare function useAxios<T, E = unknown, H = unknown>(instance?: AxiosInstance): AxiosComposables<T, E>;
